package com.phm.manage.service;

import com.phm.manage.domain.MonitorParameterConfig;

import java.util.List;

/**
 * 状态监控参数配置信息Service接口
 *
 * @author phm
 * @date 2023-08-22
 */
public interface IMonitorParameterConfigService {
    /**
     * 查询状态监控参数配置信息
     *
     * @param id 状态监控参数配置信息主键
     * @return 状态监控参数配置信息
     */
    public MonitorParameterConfig selectMonitorParameterConfigById(Long id);

    /**
     * 查询状态监控参数配置信息列表
     *
     * @param monitorParameterConfig 状态监控参数配置信息
     * @return 状态监控参数配置信息集合
     */
    public List<MonitorParameterConfig> selectMonitorParameterConfigList(MonitorParameterConfig monitorParameterConfig);

    /**
     * 新增状态监控参数配置信息
     *
     * @param monitorParameterConfig 状态监控参数配置信息
     * @return 结果
     */
    public int insertMonitorParameterConfig(MonitorParameterConfig monitorParameterConfig);

    /**
     * 修改状态监控参数配置信息
     *
     * @param monitorParameterConfig 状态监控参数配置信息
     * @return 结果
     */
    public int updateMonitorParameterConfig(MonitorParameterConfig monitorParameterConfig);

    /**
     * 批量删除状态监控参数配置信息
     *
     * @param ids 需要删除的状态监控参数配置信息主键集合
     * @return 结果
     */
    public int deleteMonitorParameterConfigByIds(Long[] ids);

    /**
     * 删除状态监控参数配置信息信息
     *
     * @param id 状态监控参数配置信息主键
     * @return 结果
     */
    public int deleteMonitorParameterConfigById(Long id);
}
